@@ -3,7 +3,7 @@ package Pod::Weaver::Plugin::Sah::Schemas;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-05-08'; # DATE
 our $DIST = 'Pod-Weaver-Plugin-Sah-Schemas'; # DIST
-our $VERSION = '0.062'; # VERSION
+our $VERSION = '0.063'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -107,20 +107,33 @@ sub weave_section {
 
                 # example on how to use
                 {
-                    push @pod, "Using with L<Data::Sah>:\n\n";
                     push @pod, <<"_";
+To check data against this schema (requires L<Data::Sah>):
+
  use Data::Sah qw(gen_validator);
- my \$vdr = gen_validator("$sch_name*");
- say \$vdr->(\$data) ? "valid" : "INVALID!";
+ my \$validator = gen_validator("$sch_name*");
+ say \$validator->(\$data) ? "valid" : "INVALID!";
 
- # Data::Sah can also create a validator to return error message, coerced value,
- # even validators in other languages like JavaScript, from the same schema.
- # See its documentation for more details.
+ # Data::Sah can also create validator that returns nice error message string
+ # and/or coerced value. Data::Sah can even create validator that targets other
+ # language, like JavaScript. All from the same schema. See its documentation
+ # for more details.
 
-_
+To validate function parameters against this schema (requires L<Params::Sah>):
 
-                    push @pod, "Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):\n\n";
-                    push @pod, <<"_";
+ use Params::Sah qw(gen_validator);
+
+ sub myfunc {
+     my \@args = \@_;
+     state \$validator = gen_validator("$sch_name*");
+     \$validator->(\\\@args);
+     ...
+ }
+
+To specify schema in L<Rinci> function metadata and use the metadata with
+L<Perinci::CmdLine> to create a CLI:
+
+ # in lib/MyApp.pm
  package MyApp;
  our \%SPEC;
  \$SPEC{myfunc} = {
@@ -138,6 +151,21 @@ _
      my \%args = \@_;
      ...
  }
+ 1;
+
+ # in myapp.pl
+ package main;
+ use Perinci::CmdLine::Any;
+ Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
+
+ # in command-line
+ % ./myapp.pl --help
+ myapp - Routine to do blah ...
+ ...
+
+ % ./myapp.pl --version
+
+ % ./myapp.pl --arg1 ...
 
 _
                 }
@@ -214,7 +242,7 @@ Pod::Weaver::Plugin::Sah::Schemas - Plugin to use when building Sah::Schemas::*
 
 =head1 VERSION
 
-This document describes version 0.062 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2020-05-08.
+This document describes version 0.063 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
